==> qunit-2.11.0.tgz: package/src/cli/utils.js <==
"use strict";

const fs = require( "fs" );
const path = require( "path" );
const { Minimatch } = require( "minimatch" );

function existsStat() {
	try {
		return fs.statSync.apply( fs, arguments );
	} catch ( e ) {
		return null;
	}
}


function getIgnoreList( baseDir ) {
	const gitFilePath = path.join( baseDir, ".gitignore" );
	if ( fs.existsSync( gitFilePath ) ) {
		const gitIgnore = fs.readFileSync( gitFilePath, "utf-8" );
		return gitIgnore.trim().split( "\n" );
	}
	return [];
}

function findFilesInternal( dir, options, result = [], prefix = "" ) {
	fs.readdirSync( dir ).forEach( ( name ) => {
		const fullName = path.join( dir, name );
		const stat = existsStat( fullName );
		if ( !stat ) {
			return;
		}
		const prefixedName = prefix + name;
		const isIgnore = options.ignores.some( ( mm ) => mm.match( prefixedName ) );
		if ( isIgnore ) {
			return;
		}
		if ( stat.isDirectory() ) {
			findFilesInternal( fullName, options, result, prefixedName + "/" );
		} else {
			const isMatch = options.matchers.some( ( mm ) => mm.match( prefixedName ) );
			if ( isMatch ) {
				result.push( prefixedName );
			}
		}
	} );
	return result;
}

function findFiles( baseDir, options ) {
	return findFilesInternal( baseDir, {
		matchers: ( options.match || [] ).map( ( pattern ) => new Minimatch( pattern ) ),
		ignores: ( options.ignore || [] ).map( ( pattern ) => new Minimatch( pattern ) )
	} );
}

function getFilesFromArgs( args ) {
	const globs = args.slice();

	// Default to files in the test directory
	if ( !globs.length ) {
		globs.push( "test/**/*.js" );
	}

	const files = [];
	const filteredGlobs = [];

	// For each of the potential globs, we check if it is a directory path and
	// update it so that it matches the JS files in that directory.
	globs.forEach( glob => {
		const stat = existsStat( glob );

		if ( stat && stat.isFile() ) {

			// Remember known files to avoid (slow) directory-wide glob scanning.
			// https://github.com/qunitjs/qunit/pull/1385
			files.push( glob );
		} else if ( stat && stat.isDirectory() ) {
			filteredGlobs.push( `${glob}/**/*.js` );
		} else {
			filteredGlobs.push( glob );
		}
	} );

	if ( filteredGlobs.length ) {
		files.push.apply( files, findFiles( process.cwd(), { match: filteredGlobs } ) );
	}

	if ( !files.length ) {
		error( "No files were found matching: " + args.join( ", " ) );
	}

	return files;
}

function error( message ) {
	console.error( message );
	process.exit( 1 );
}

function capitalize( string ) {
	return string.charAt( 0 ).toUpperCase() + string.slice( 1 );
}

module.exports = {
	findFiles,
	capitalize,
	error,
	getFilesFromArgs,
	getIgnoreList
};

==> qunit-2.12.0.tgz: package/src/cli/utils.js <==
"use strict";

const fs = require( "fs" );
const path = require( "path" );
const glob = require( "tiny-glob/sync" );

function existsStat() {
	try {
		return fs.statSync.apply( fs, arguments );
	} catch ( e ) {
		return null;
	}
}


function getIgnoreList( baseDir ) {
	const gitFilePath = path.join( baseDir, ".gitignore" );
	if ( fs.existsSync( gitFilePath ) ) {
		const gitIgnore = fs.readFileSync( gitFilePath, "utf-8" );
		return gitIgnore.trim().split( "\n" );
	}
	return [];
}

function getFilesFromArgs( args ) {
	const patterns = args.slice();

	// Default to files in the test directory
	if ( !patterns.length ) {
		patterns.push( "test/**/*.js" );
	}

	const files = new Set();

	// For each of the potential globs, we check if it is a directory path and
	// update it so that it matches the JS files in that directory.
	patterns.forEach( pattern => {
		const stat = existsStat( pattern );

		if ( stat && stat.isFile() ) {

			// Optimisation:
			// For non-glob simple files, skip (slow) directory-wide scanning.
			// https://github.com/qunitjs/qunit/pull/1385
			files.add( pattern );
		} else {
			if ( stat && stat.isDirectory() ) {
				pattern = `${pattern}/**/*.js`;
			}
			const results = glob( pattern, {
				cwd: process.cwd(),
				filesOnly: true,
				flush: true
			} );
			for ( const result of results ) {
				files.add( result );
			}
		}
	} );

	if ( !files.size ) {
		error( "No files were found matching: " + args.join( ", " ) );
	}

	return Array.from( files ).sort();
}

function error( message ) {
	console.error( message );
	process.exit( 1 );
}

function capitalize( string ) {
	return string.charAt( 0 ).toUpperCase() + string.slice( 1 );
}

module.exports = {
	capitalize,
	error,
	getFilesFromArgs,
	getIgnoreList
};
